scoretools.add_double_bar_to_end_of_score
=========================================

.. autofunction:: abjad.tools.scoretools.add_double_bar_to_end_of_score.add_double_bar_to_end_of_score
   :noindex:
